@@ -15,12 +15,20 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from pytest_bdd import scenarios
+import pytest
 
-from step_definitions.application import *
-from step_definitions.interface import *
-from step_definitions.service import *
-from step_definitions.site import *
-from step_definitions.system import *
+try:
+    from pytest_bdd import scenarios
+except ImportError:
+    pytestmark = pytest.mark.skip(reason='pytest_bdd is not installed')
+else:
+    from step_definitions.application import *
+    from step_definitions.interface import *
+    from step_definitions.service import *
+    from step_definitions.site import *
+    from step_definitions.system import *
 
-scenarios('features')
+    # Mark all tests are functional
+    pytestmark = pytest.mark.functional
+
+    scenarios('features')
