@@ -30,6 +30,9 @@ from django.utils.translation import ugettext as _
 
 logger = logging.getLogger(__name__)
 
+UWSGI_ENABLED_PATH = '/etc/uwsgi/apps-enabled/{config_name}.ini'
+UWSGI_AVAILABLE_PATH = '/etc/uwsgi/apps-available/{config_name}.ini'
+
 
 def is_systemd_running():
     """Return if we are running under systemd."""
@@ -123,7 +126,7 @@ def service_reload(service_name):
 
 
 def service_action(service_name, action):
-    """Preform the given action on the service_name."""
+    """Perform the given action on the service_name."""
     if is_systemd_running():
         subprocess.run(['systemctl', action, service_name],
                        stdout=subprocess.DEVNULL)
@@ -219,7 +222,7 @@ class WebserverChange(object):
     def __exit__(self, exc_type, exc_value, traceback):
         """Restart or reload the webserver.
 
-        Don't supress exceptions.  If an exception occurs
+        Don't suppress exceptions.  If an exception occurs
         restart/reload the webserver based on enable/disable
         operations done so far.
         """
@@ -245,6 +248,43 @@ class WebserverChange(object):
         self.actions_required.add(action_required)
 
 
+def uwsgi_is_enabled(config_name):
+    """Return whether a uwsgi config is enabled."""
+    enabled_path = UWSGI_ENABLED_PATH.format(config_name=config_name)
+    return os.path.exists(enabled_path)
+
+
+def uwsgi_enable(config_name):
+    """Enable a uwsgi configuration that runs under uwsgi."""
+    if uwsgi_is_enabled(config_name):
+        return
+
+    # uwsgi is started/stopped using init script. We don't know if it can
+    # handle some configuration already running against newly enabled
+    # configuration. So, stop first before enabling new configuration.
+    service_stop('uwsgi')
+
+    enabled_path = UWSGI_ENABLED_PATH.format(config_name=config_name)
+    available_path = UWSGI_AVAILABLE_PATH.format(config_name=config_name)
+    os.symlink(available_path, enabled_path)
+
+    service_enable('uwsgi')
+    service_start('uwsgi')
+
+
+def uwsgi_disable(config_name):
+    """Disable a uwsgi configuration that runs under uwsgi."""
+    if not uwsgi_is_enabled(config_name):
+        return
+
+    # If uwsgi is restarted later, it won't stop the just disabled
+    # configuration due to how init scripts are written for uwsgi.
+    service_stop('uwsgi')
+    enabled_path = UWSGI_ENABLED_PATH.format(config_name=config_name)
+    os.unlink(enabled_path)
+    service_start('uwsgi')
+
+
 def diagnose_port_listening(port, kind='tcp', listen_address=None):
     """Run a diagnostic on whether a port is being listened on.
 
@@ -308,13 +348,10 @@ def _check_port(port, kind='tcp', listen_address=None):
     return False
 
 
-def diagnose_url(url, kind=None, env=None, check_certificate=True,
-                 extra_options=None, wrapper=None, expected_output=None):
-    """Run a diagnostic on whether a URL is accessible.
-
-    Kind can be '4' for IPv4 or '6' for IPv6.
-    """
-    command = ['curl', '-f', '-w', '%{response_code}', url]
+def check_url(url, kind=None, env=None, check_certificate=True,
+              extra_options=None, wrapper=None, expected_output=None):
+    """Check whether a URL is accessible."""
+    command = ['curl', '--location', '-f', '-w', '%{response_code}', url]
 
     if wrapper:
         command.insert(0, wrapper)
@@ -343,13 +380,25 @@ def diagnose_url(url, kind=None, env=None, check_certificate=True,
     except FileNotFoundError:
         result = 'error'
 
+    return result
+
+
+def diagnose_url(url, kind=None, env=None, check_certificate=True,
+                 extra_options=None, wrapper=None, expected_output=None):
+    """Run a diagnostic on whether a URL is accessible.
+
+    Kind can be '4' for IPv4 or '6' for IPv6.
+    """
+    result = check_url(url, kind, env, check_certificate, extra_options,
+                       wrapper, expected_output)
+
     if kind:
         return [
             _('Access URL {url} on tcp{kind}').format(url=url, kind=kind),
             result
         ]
-    else:
-        return [_('Access URL {url}').format(url=url), result]
+
+    return [_('Access URL {url}').format(url=url), result]
 
 
 def diagnose_url_on_all(url, **kwargs):
@@ -386,7 +435,7 @@ def diagnose_netcat(host, port, input='', negate=False):
 
 
 def get_addresses():
-    """Return a list of IP addreses and hostnames."""
+    """Return a list of IP addresses and hostnames."""
     addresses = get_ip_addresses()
 
     hostname = get_hostname()
