@@ -26,15 +26,14 @@ from django.conf import settings
 from django.forms import CheckboxInput
 from django.utils import translation
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import get_language_info
+from django.utils.translation import ugettext_lazy as _
 
 import plinth
-from plinth import utils
 
 
-class ServiceForm(forms.Form):
-    """Generic configuration form for a service."""
+class AppForm(forms.Form):
+    """Generic configuration form for an app."""
     is_enabled = forms.BooleanField(
         label=_('Enable application'), required=False)
 
@@ -46,7 +45,10 @@ class DomainSelectionForm(forms.Form):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.fields['domain_name'].choices = utils.get_domain_names()
+
+        from plinth.modules.names.components import DomainName
+        domains = list(DomainName.list_names())
+        self.fields['domain_name'].choices = zip(domains, domains)
 
     domain_name = forms.ChoiceField(
         label=_('Select a domain name to be used with this application'),
@@ -69,14 +71,21 @@ class LanguageSelectionFormMixin:
         supported_languages = [
             (None, _('Use the language preference set in the browser'))
         ]
+
+        def _get_local_name(language_code, language_name):
+            try:
+                return get_language_info(language_code)['name_local']
+            except KeyError:
+                return language_name
+
         for language_code, language_name in settings.LANGUAGES:
             locale_code = translation.to_locale(language_code)
             plinth_dir = os.path.dirname(plinth.__file__)
             if language_code == 'en' or os.path.exists(
                     os.path.join(plinth_dir, 'locale', locale_code)):
-                supported_languages.append(
-                    (language_code,
-                     get_language_info(language_code)['name_local']))
+                supported_languages.append((language_code,
+                                            _get_local_name(
+                                                language_code, language_name)))
 
         self.fields['language'].choices = supported_languages
 
