@@ -25,16 +25,16 @@ from django.core.serializers.json import DjangoJSONEncoder
 from django.http import HttpResponse
 from django.templatetags.static import static
 
-from plinth import frontpage, module_loader
+from plinth import frontpage
 from plinth.modules import names
 
 
 def access_info(request, **kwargs):
     """API view to return a list of domains and types."""
     domains = [{
-        'domain': domain,
-        'type': domain_type
-    } for domain_type, domains in names.domains.items() for domain in domains]
+        'domain': domain.name,
+        'type': domain.domain_type.component_id
+    } for domain in names.components.DomainName.list()]
     response = {'domains': domains}
 
     return HttpResponse(json.dumps(response), content_type='application/json')
@@ -44,27 +44,35 @@ def shortcuts(request, **kwargs):
     """API view to return the list of frontpage services."""
     # XXX: Get the module (or module name) from shortcut properly.
     username = str(request.user) if request.user.is_authenticated else None
-    shortcuts = [
-        _get_shortcut_data(shortcut['id'].split('_')[0], shortcut)
-        for shortcut in frontpage.get_shortcuts(username)
-    ]
-    response = {'shortcuts': shortcuts}
+    response = get_shortcuts_as_json(username)
     return HttpResponse(
         json.dumps(response, cls=DjangoJSONEncoder),
         content_type='application/json')
 
 
-def _get_shortcut_data(module_name, shortcut):
+def get_shortcuts_as_json(username=None):
+    shortcuts = [
+        _get_shortcut_data(shortcut)
+        for shortcut in frontpage.Shortcut.list(username)
+        if shortcut.component_id and shortcut.is_enabled()
+    ]
+    custom_shortcuts = frontpage.get_custom_shortcuts()
+    if custom_shortcuts:
+        shortcuts += custom_shortcuts['shortcuts']
+    return {'shortcuts': shortcuts}
+
+
+def _get_shortcut_data(shortcut):
     """Return detailed information about a shortcut."""
-    module = module_loader.loaded_modules[module_name]
     shortcut_data = {
-        'name': shortcut['name'],
-        'short_description': shortcut['short_description'],
-        'description': shortcut['details'],
-        'icon_url': _get_icon_url(shortcut['icon']),
-        'clients': copy.deepcopy(getattr(module, 'clients', None))
+        'name': shortcut.name,
+        'short_description': shortcut.short_description,
+        'description': shortcut.description,
+        'icon_url': _get_icon_url(shortcut.icon),
+        'clients': copy.deepcopy(shortcut.clients),
     }
-    if module_name == 'ikiwiki':
+    # XXX: Fix the hardcoding
+    if shortcut.name.startswith('shortcut-ikiwiki-'):
         shortcut_data['clients'][0]['platforms'][0]['url'] += '/{}'.format(
             shortcut['name'])
     return shortcut_data
