@@ -20,11 +20,15 @@ FreedomBox app for service discovery.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import actions, cfg
-from plinth.menu import main_menu
+from plinth import actions
+from plinth import app as app_module
+from plinth import cfg, menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import ServiceView
+from plinth.views import AppView
+
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 # pylint: disable=C0103
 
@@ -49,19 +53,37 @@ description = [
           'hostile local network.'), box_name=_(cfg.box_name))
 ]
 
-service = None
-
 manual_page = 'ServiceDiscovery'
 
+app = None
+
+
+class AvahiApp(app_module.App):
+    """FreedomBox app for Avahi."""
+
+    app_id = 'avahi'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-avahi', name, None, 'fa-compass',
+                              'avahi:index', parent_url_name='system')
+        self.add(menu_item)
+
+        firewall = Firewall('firewall-avahi', name, ports=['mdns'],
+                            is_external=False)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-avahi', managed_services[0])
+        self.add(daemon)
+
 
 def init():
-    """Intialize the service discovery module."""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-lamp', 'avahi:index')
-
-    global service  # pylint: disable=W0603
-    service = service_module.Service(managed_services[0], name, ports=['mdns'],
-                                     is_external=False)
+    """Initialize the service discovery module."""
+    global app
+    app = AvahiApp()
+    if app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
@@ -74,7 +96,8 @@ def setup(helper, old_version=None):
                 ['reload', 'avahi-daemon'])
 
 
-class AvahiServiceView(ServiceView):
-    service_id = managed_services[0]
+class AvahiAppView(AppView):
+    app_id = 'avahi'
+    name = name
     description = description
     manual_page = manual_page
