@@ -20,15 +20,15 @@ URLs for Cockpit module.
 
 from django.conf.urls import url
 
-from plinth.views import ServiceView
 from plinth.modules import cockpit
+from plinth.views import AppView
 
 urlpatterns = [
-    url(r'^sys/cockpit/$',
-        ServiceView.as_view(
-            service_id=cockpit.managed_services[0],
-            diagnostics_module_name='cockpit',
-            description=cockpit.description,
-            show_status_block=True),
-        name='index'),
+    url(
+        r'^sys/cockpit/$',
+        AppView.as_view(app_id='cockpit', name=cockpit.name,
+                        diagnostics_module_name='cockpit',
+                        description=cockpit.description,
+                        show_status_block=True, clients=cockpit.clients,
+                        manual_page=cockpit.manual_page), name='index'),
 ]
