@@ -42,10 +42,14 @@ def domain_label_validator(domainname):
             raise ValidationError(_('Invalid domain name'))
 
 
-def get_default_app_choices():
-    shortcuts = frontpage.get_shortcuts(web_apps_only=True, sort_by='name')
-    apps = [(shortcut['id'], shortcut['name']) for shortcut in shortcuts]
-    return [('plinth', 'FreedomBox Service (Plinth)')] + apps
+def get_homepage_choices():
+    """Return list of drop down choices for home page."""
+    shortcuts = frontpage.Shortcut.list(web_apps_only=True)
+    shortcut_choices = [(shortcut.component_id, shortcut.name)
+                        for shortcut in shortcuts if shortcut.is_enabled()]
+    apache_default = ('apache-default', _('Apache Default'))
+    plinth = ('plinth', _('FreedomBox Service (Plinth)'))
+    return [apache_default, plinth] + shortcut_choices
 
 
 class ConfigurationForm(forms.Form):
@@ -58,11 +62,12 @@ class ConfigurationForm(forms.Form):
     hostname = forms.CharField(
         label=ugettext_lazy('Hostname'), help_text=format_lazy(
             ugettext_lazy(
-                'Hostname is the local name by which other devices on the local '
-                'network can reach your {box_name}.  It must start and end with '
-                'an alphabet or a digit and have as interior characters only '
-                'alphabets, digits and hyphens.  Total length must be 63 '
-                'characters or less.'), box_name=ugettext_lazy(cfg.box_name)),
+                'Hostname is the local name by which other devices on the '
+                'local network can reach your {box_name}.  It must start and '
+                'end with an alphabet or a digit and have as interior '
+                'characters only alphabets, digits and hyphens.  Total '
+                'length must be 63 characters or less.'),
+            box_name=ugettext_lazy(cfg.box_name)),
         validators=[
             validators.RegexValidator(HOSTNAME_REGEX,
                                       ugettext_lazy('Invalid hostname'))
@@ -72,27 +77,33 @@ class ConfigurationForm(forms.Form):
         label=ugettext_lazy('Domain Name'), help_text=format_lazy(
             ugettext_lazy(
                 'Domain name is the global name by which other devices on the '
-                'Internet can reach your {box_name}.  It must consist of labels '
-                'separated by dots.  Each label must start and end with an '
-                'alphabet or a digit and have as interior characters only '
-                'alphabets, digits and hyphens.  Length of each label must be 63 '
-                'characters or less.  Total length of domain name must be 253 '
-                'characters or less.'), box_name=ugettext_lazy(cfg.box_name)),
+                'Internet can reach your {box_name}.  It must consist of '
+                'labels separated by dots.  Each label must start and end '
+                'with an alphabet or a digit and have as interior characters '
+                'only alphabets, digits and hyphens.  Length of each label '
+                'must be 63 characters or less.  Total length of domain name '
+                'must be 253 characters or less.'),
+            box_name=ugettext_lazy(cfg.box_name)),
         required=False, validators=[
             validators.RegexValidator(
                 r'^[a-zA-Z0-9]([-a-zA-Z0-9.]{,251}[a-zA-Z0-9])?$',
                 ugettext_lazy('Invalid domain name')), domain_label_validator
         ], strip=True)
 
-    defaultapp = forms.ChoiceField(
-        label=ugettext_lazy('Default App'), help_text=format_lazy(
+    homepage = forms.ChoiceField(
+        label=ugettext_lazy('Webserver Home Page'), help_text=format_lazy(
             ugettext_lazy(
-                'Choose the default web application that must be served when '
+                'Choose the default page that must be served when '
                 'someone visits your {box_name} on the web. A typical use '
-                'case is to set your blog or wiki as the landing page when '
-                'someone visits the domain name. Note that once the default '
-                'app is set to something other than {box_name} Service '
+                'case is to set your blog or wiki as the home page when '
+                'someone visits the domain name. Note that once the home '
+                'page is set to something other than {box_name} Service '
                 '(Plinth), your users must explicitly type /plinth or '
                 '/freedombox to reach {box_name} Service (Plinth).'),
             box_name=ugettext_lazy(cfg.box_name)), required=False,
-        choices=get_default_app_choices)
+        choices=get_homepage_choices)
+
+    advanced_mode = forms.BooleanField(
+        label=_('Show advanced apps and features'), required=False,
+        help_text=_('Show apps and features that require more technical '
+                    'knowledge.'))
