@@ -25,10 +25,9 @@ from django.template.response import TemplateResponse
 from django.utils.translation import ugettext as _
 
 from plinth import actions
-from plinth.modules import config, firewall
-from plinth.modules.names import SERVICES
-from plinth.signals import (domain_added, domain_removed, domainname_change,
-                            post_hostname_change, pre_hostname_change)
+from plinth.modules import config
+from plinth.signals import (domain_added, domain_removed, post_hostname_change,
+                            pre_hostname_change)
 
 from .forms import ConfigurationForm
 
@@ -37,7 +36,7 @@ LOGGER = logging.getLogger(__name__)
 
 def index(request):
     """Serve the configuration form"""
-    status = get_status(request)
+    status = get_status()
 
     if request.method == 'POST':
         form = ConfigurationForm(request.POST, initial=status,
@@ -45,7 +44,7 @@ def index(request):
         # pylint: disable-msg=E1101
         if form.is_valid():
             _apply_changes(request, status, form.cleaned_data)
-            status = get_status(request)
+            status = get_status()
             form = ConfigurationForm(initial=status, prefix='configuration')
     else:
         form = ConfigurationForm(initial=status, prefix='configuration')
@@ -58,11 +57,13 @@ def index(request):
         })
 
 
-def get_status(request):
+def get_status():
     """Return the current status"""
     return {
         'hostname': config.get_hostname(),
         'domainname': config.get_domainname(),
+        'homepage': config.get_home_page(),
+        'advanced_mode': config.get_advanced_mode(),
     }
 
 
@@ -72,22 +73,51 @@ def _apply_changes(request, old_status, new_status):
         try:
             set_hostname(new_status['hostname'])
         except Exception as exception:
-            messages.error(request,
-                           _('Error setting hostname: {exception}')
-                           .format(exception=exception))
+            messages.error(
+                request,
+                _('Error setting hostname: {exception}').format(
+                    exception=exception))
         else:
             messages.success(request, _('Hostname set'))
 
     if old_status['domainname'] != new_status['domainname']:
         try:
-            set_domainname(new_status['domainname'])
+            set_domainname(new_status['domainname'], old_status['domainname'])
         except Exception as exception:
-            messages.error(request,
-                           _('Error setting domain name: {exception}')
-                           .format(exception=exception))
+            messages.error(
+                request,
+                _('Error setting domain name: {exception}').format(
+                    exception=exception))
         else:
             messages.success(request, _('Domain name set'))
 
+    if old_status['homepage'] != new_status['homepage']:
+        try:
+            config.change_home_page(new_status['homepage'])
+        except Exception as exception:
+            messages.error(
+                request,
+                _('Error setting webserver home page: {exception}').format(
+                    exception=exception))
+        else:
+            messages.success(request, _('Webserver home page set'))
+
+    if old_status['advanced_mode'] != new_status['advanced_mode']:
+        try:
+            config.set_advanced_mode(new_status['advanced_mode'])
+        except Exception as exception:
+            messages.error(
+                request,
+                _('Error changing advanced mode: {exception}').format(
+                    exception=exception))
+        else:
+            if new_status['advanced_mode']:
+                messages.success(request,
+                                 _('Showing advanced apps and features'))
+            else:
+                messages.success(request,
+                                 _('Hiding advanced apps and features'))
+
 
 def set_hostname(hostname):
     """Sets machine hostname to hostname"""
@@ -95,7 +125,7 @@ def set_hostname(hostname):
     domainname = config.get_domainname()
 
     # Hostname should be ASCII. If it's unicode but passed our
-    # valid_hostname check, convert to ASCII.
+    # valid_hostname check, convert
     hostname = str(hostname)
 
     pre_hostname_change.send_robust(sender='config', old_hostname=old_hostname,
@@ -111,7 +141,7 @@ def set_hostname(hostname):
     actions.superuser_run('domainname-change', [domainname])
 
 
-def set_domainname(domainname):
+def set_domainname(domainname, old_domainname):
     """Sets machine domain name to domainname"""
     old_domainname = config.get_domainname()
 
@@ -121,21 +151,13 @@ def set_domainname(domainname):
     LOGGER.info('Changing domain name to - %s', domainname)
     actions.superuser_run('domainname-change', [domainname])
 
-    domainname_change.send_robust(sender='config',
-                                  old_domainname=old_domainname,
-                                  new_domainname=domainname)
-
     # Update domain registered with Name Services module.
-    domain_removed.send_robust(sender='config', domain_type='domainname')
-    if domainname:
-        try:
-            domainname_services = firewall.get_enabled_services(
-                zone='external')
-        except actions.ActionError:
-            # This happens when firewalld is not installed.
-            # TODO: Are these services actually enabled?
-            domainname_services = [service[0] for service in SERVICES]
+    if old_domainname:
+        domain_removed.send_robust(sender='config',
+                                   domain_type='domain-type-static',
+                                   name=old_domainname)
 
-        domain_added.send_robust(sender='config', domain_type='domainname',
-                                 name=domainname, description=_('Domain Name'),
-                                 services=domainname_services)
+    if domainname:
+        domain_added.send_robust(sender='config',
+                                 domain_type='domain-type-static',
+                                 name=domainname, services='__all__')
