@@ -20,11 +20,14 @@ Plinth module to configure coquelicot.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 
-from .manifest import clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 clients = clients
 
@@ -48,74 +51,56 @@ description = [
       'The default upload password is "test".')
 ]
 
-service = None
-
 manual_page = 'Coquelicot'
 
+app = None
+
+
+class CoquelicotApp(app_module.App):
+    """FreedomBox app for Coquelicot."""
+
+    app_id = 'coquelicot'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-coquelicot', name, short_description,
+                              'coquelicot', 'coquelicot:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut('shortcut-coquelicot', name,
+                                      short_description=short_description,
+                                      icon='coquelicot', url='/coquelicot',
+                                      clients=clients, login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-coquelicot', name,
+                            ports=['http', 'https'], is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-coquelicot', 'coquelicot-freedombox')
+        self.add(webserver)
+
+        daemon = Daemon('daemon-coquelicot', managed_services[0])
+        self.add(daemon)
+
 
 def init():
-    """Intialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'coquelicot', 'coquelicot:index',
-                     short_description)
+    """Initialize the module."""
+    global app
+    app = CoquelicotApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable,
-                                         is_running=is_running)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'coquelicot', ['setup'])
-    helper.call('post', actions.superuser_run, 'coquelicot', ['enable'])
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable,
-                                         is_running=is_running)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    """Helper method to add a shortcut to the frontpage."""
-    frontpage.add_shortcut('coquelicot', name,
-                           short_description=short_description,
-                           url='/coquelicot', login_required=True)
-
-
-def is_running():
-    """Return whether the service is running."""
-    return action_utils.service_is_running('coquelicot')
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return (action_utils.service_is_enabled('coquelicot')
-            and action_utils.webserver_is_enabled('coquelicot-freedombox'))
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('coquelicot', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Disable the module."""
-    actions.superuser_run('coquelicot', ['disable'])
-    frontpage.remove_shortcut('coquelicot')
+    helper.call('post', app.enable)
 
 
 def get_current_max_file_size():
