@@ -24,19 +24,22 @@ from django.utils.translation import ugettext as _
 from plinth import actions, views
 from plinth.errors import ActionError
 from plinth.modules.coquelicot import (clients, description,
-                                       get_current_max_file_size)
+                                       get_current_max_file_size, manual_page,
+                                       name)
 
 from .forms import CoquelicotForm
 
 
-class CoquelicotServiceView(views.ServiceView):
+class CoquelicotAppView(views.AppView):
     """Serve configuration page."""
     clients = clients
+    name = name
     description = description
     diagnostics_module_name = 'coquelicot'
-    service_id = 'coquelicot'
+    app_id = 'coquelicot'
     form_class = CoquelicotForm
     show_status_block = True
+    manual_page = manual_page
 
     def get_initial(self):
         """Return the status of the service to fill in the form."""
@@ -54,7 +57,7 @@ class CoquelicotServiceView(views.ServiceView):
                     'coquelicot', ['set-upload-password'],
                     input=form_data['upload_password'].encode())
                 messages.success(self.request, _('Upload password updated'))
-            except ActionError as e:
+            except ActionError:
                 messages.error(self.request,
                                _('Failed to update upload password'))
 
@@ -65,7 +68,7 @@ class CoquelicotServiceView(views.ServiceView):
                     'coquelicot', ['set-max-file-size',
                                    str(max_file_size)])
                 messages.success(self.request, _('Maximum file size updated'))
-            except ActionError as e:
+            except ActionError:
                 messages.error(self.request,
                                _('Failed to update maximum file size'))
 
