@@ -22,16 +22,19 @@ import subprocess
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import menu
+from plinth.daemon import Daemon
 
-version = 1
+from .manifest import backup # noqa, pylint: disable=unused-import
+
+version = 2
 
 is_essential = True
 
-managed_services = ['ntp']
+managed_services = ['systemd-timesyncd']
 
-managed_packages = ['ntp']
+managed_packages = []
 
 name = _('Date & Time')
 
@@ -42,47 +45,55 @@ description = [
 
 manual_page = 'DateTime'
 
-service = None
+app = None
+
+
+class DateTimeApp(app_module.App):
+    """FreedomBox app for date and time."""
+
+    app_id = 'datetime'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-datetime', name, None, 'fa-clock-o',
+                              'datetime:index', parent_url_name='system')
+        self.add(menu_item)
+
+        daemon = Daemon('daemon-datetime', managed_services[0])
+        self.add(daemon)
 
 
 def init():
-    """Intialize the date/time module."""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-time', 'datetime:index')
-
-    global service
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['ntp'], is_external=False)
+    """Initialize the date/time module."""
+    global app
+    app = DateTimeApp()
+    if app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
-    helper.install(managed_packages)
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['ntp'], is_external=False)
-    helper.call('post', service.notify_enabled, None, True)
+    helper.call('post', app.enable)
 
 
 def diagnose():
     """Run diagnostics and return the results."""
     results = []
-    results.append(_diagnose_ntp_server_count())
+    results.append(_diagnose_time_synchronized())
 
     return results
 
 
-def _diagnose_ntp_server_count():
-    """Diagnose minimum NTP server count."""
+def _diagnose_time_synchronized():
+    """Check whether time is synchronized to NTP server."""
     result = 'failed'
     try:
-        output = subprocess.check_output(['ntpq', '-n', '-c', 'lpeers'])
-        if len(output.decode().splitlines()[2:]):
+        output = subprocess.check_output(
+            ['timedatectl', 'show', '--property=NTPSynchronized', '--value'])
+        if 'yes' in output.decode():
             result = 'passed'
     except subprocess.CalledProcessError:
         pass
 
-    return [_('NTP client in contact with servers'), result]
+    return [_('Time synchronized to NTP server'), result]
