@@ -20,17 +20,18 @@ FreedomBox app to configure a Deluge web client.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import register_group
 
-from .manifest import backup, clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 2
 
-service = None
-
 managed_services = ['deluge-web']
 
 managed_packages = ['deluged', 'deluge-web']
@@ -55,61 +56,54 @@ clients = clients
 
 manual_page = 'Deluge'
 
+app = None
+
+
+class DelugeApp(app_module.App):
+    """FreedomBox app for Deluge."""
+
+    app_id = 'deluge'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-deluge', name, short_description, 'deluge',
+                              'deluge:index', parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-deluge', name, short_description=short_description,
+            url='/deluge', icon='deluge', clients=clients, login_required=True,
+            allowed_groups=[group[0]])
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-deluge', name, ports=['http', 'https'],
+                            is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-deluge', 'deluge-plinth')
+        self.add(webserver)
+
+        daemon = Daemon('daemon-deluge', managed_services[0])
+        self.add(daemon)
+
 
 def init():
     """Initialize the Deluge module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'deluge', 'deluge:index',
-                     short_description)
+    global app
+    app = DelugeApp()
     register_group(group)
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-    helper.call('post', actions.superuser_run, 'deluge', ['enable'])
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut('deluge', name, short_description, url='/deluge',
-                           login_required=True, allowed_groups=[group[0]])
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return (action_utils.webserver_is_enabled('deluge-plinth')
-            and action_utils.service_is_enabled('deluge-web'))
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('deluge', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Disable the module."""
-    actions.superuser_run('deluge', ['disable'])
-    frontpage.remove_shortcut('deluge')
+    helper.call('post', actions.superuser_run, 'deluge', ['setup'])
+    helper.call('post', app.enable)
 
 
 def diagnose():
