@@ -21,7 +21,10 @@ FreedomBox app for system diagnostics.
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import action_utils
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import menu
+
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -37,11 +40,27 @@ description = [
 
 manual_page = 'Diagnostics'
 
+app = None
+
+
+class DiagnosticsApp(app_module.App):
+    """FreedomBox app for diagnostics."""
+
+    app_id = 'diagnostics'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-diagnostics', name, None, 'fa-heartbeat',
+                              'diagnostics:index', parent_url_name='system')
+        self.add(menu_item)
+
 
 def init():
     """Initialize the module"""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-screenshot', 'diagnostics:index')
+    global app
+    app = DiagnosticsApp()
+    app.set_enabled(True)
 
 
 def diagnose():
