@@ -20,6 +20,7 @@ Help app for FreedomBox.
 
 import mimetypes
 import os
+import subprocess
 
 from apt.cache import Cache
 from django.core.files.base import File
@@ -28,40 +29,63 @@ from django.template.response import TemplateResponse
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
 
-from plinth import __version__, cfg
-from plinth.menu import main_menu
+from plinth import __version__, actions
+from plinth import app as app_module
+from plinth import cfg, menu
+
+app = None
+
+
+class HelpApp(app_module.App):
+    """FreedomBox app for showing help."""
+
+    app_id = 'help'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-help', ugettext_lazy('Documentation'),
+                              None, 'fa-book', 'help:index',
+                              parent_url_name='index')
+        self.add(menu_item)
+        menu_item = menu.Menu('menu-help-manual', ugettext_lazy('Manual'),
+                              None, 'fa-info-circle', 'help:manual',
+                              parent_url_name='help:index', order=10)
+        self.add(menu_item)
+        menu_item = menu.Menu('menu-help-download-manual',
+                              ugettext_lazy('Download Manual'), None,
+                              'fa-download', 'help:download-manual',
+                              parent_url_name='help:index', order=15)
+        self.add(menu_item)
+        menu_item = menu.Menu('menu-help-about', ugettext_lazy('About'), None,
+                              'fa-star', 'help:about',
+                              parent_url_name='help:index', order=100)
+        self.add(menu_item)
 
 
 def init():
     """Initialize the Help module"""
-    menu = main_menu.add_urlname(
-        ugettext_lazy('Documentation'), 'glyphicon-book', 'help:index')
-    menu.add_urlname(
-        ugettext_lazy('Manual'), 'glyphicon-info-sign', 'help:manual',
-        order=10)
-    menu.add_urlname(
-        ugettext_lazy('Download Manual'), 'glyphicon-download-alt',
-        'help:download-manual', order=15)
-    menu.add_urlname(
-        ugettext_lazy('About'), 'glyphicon-star', 'help:about', order=100)
+    global app
+    app = HelpApp()
+    app.set_enabled(True)
 
 
 def index(request):
     """Serve the index page"""
-    return TemplateResponse(request, 'help_index.html', {
-        'title': _('Documentation and FAQ')
-    })
+    return TemplateResponse(request, 'help_index.html',
+                            {'title': _('Documentation and FAQ')})
 
 
 def about(request):
     """Serve the about page"""
     cache = Cache()
-    plinth = cache['plinth']
+    freedombox = cache['freedombox']
     context = {
         'title': _('About {box_name}').format(box_name=_(cfg.box_name)),
         'version': __version__,
-        'new_version': not plinth.candidate.is_installed,
-        'os_release': get_os_release()
+        'new_version': not freedombox.candidate.is_installed,
+        'os_release': get_os_release(),
+        'backports_in_use': get_backports_in_use(),
     }
     return TemplateResponse(request, 'help_about.html', context)
 
@@ -106,12 +130,8 @@ def download_manual(request):
 
 def status_log(request):
     """Serve the last 100 lines of plinth's status log"""
-    num_lines = 100
-    with open(cfg.status_log_file, 'r') as log_file:
-        data = log_file.readlines()
-
-    data = ''.join(data[-num_lines:])
-    context = {'num_lines': num_lines, 'data': data}
+    output = actions.superuser_run('help', ['get-logs'])
+    context = {'num_lines': 100, 'data': output}
     return TemplateResponse(request, 'statuslog.html', context)
 
 
@@ -125,3 +145,16 @@ def get_os_release():
                 line = line.split('=')
                 output = line[1]
     return output
+
+
+def get_backports_in_use():
+    """Return whether backports packages are installed."""
+    # Only freedombox package is set to be installed from backports currently.
+    output = subprocess.check_output(['apt-cache', 'policy', 'freedombox'])
+    for line in output.decode().split('\n'):
+        if 'Installed:' in line:
+            version = line.strip().split(': ')[1]
+            if 'bpo' in version:
+                return True
+
+    return False
