@@ -18,15 +18,18 @@
 FreedomBox app to configure ikiwiki.
 """
 
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, cfg, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import register_group
 from plinth.utils import format_lazy
 
-from .manifest import clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -35,8 +38,6 @@ managed_packages = [
     'libsearch-xapian-perl', 'libimage-magick-perl'
 ]
 
-service = None
-
 name = _('ikiwiki')
 
 short_description = _('Wiki and Blog')
@@ -50,9 +51,10 @@ description = [
     format_lazy(
         _('Only {box_name} users in the <b>admin</b> group can <i>create</i> '
           'and <i>manage</i> blogs and wikis, but any user in the <b>wiki</b> '
-          'group can <i>edit</i> existing ones. In the <a href="/plinth/sys/'
-          'users">User Configuration</a> you can change these '
-          'permissions or add new users.'), box_name=_(cfg.box_name))
+          'group can <i>edit</i> existing ones. In the <a href="{users_url}">'
+          'User Configuration</a> you can change these '
+          'permissions or add new users.'), box_name=_(cfg.box_name),
+        users_url=reverse_lazy('users:index'))
 ]
 
 clients = clients
@@ -61,61 +63,64 @@ group = ('wiki', _('View and edit wiki applications'))
 
 manual_page = 'Ikiwiki'
 
+app = None
+
+
+class IkiwikiApp(app_module.App):
+    """FreedomBox app for Ikiwiki."""
+
+    app_id = 'ikiwiki'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-ikiwiki', name, short_description,
+                              'ikiwiki', 'ikiwiki:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        sites = actions.run('ikiwiki', ['get-sites']).split('\n')
+        sites = [name for name in sites if name != '']
+        for site in sites:
+            self.add_shortcut(site)
+
+        firewall = Firewall('firewall-ikiwiki', name, ports=['http', 'https'],
+                            is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-ikiwiki', 'ikiwiki-plinth')
+        self.add(webserver)
+
+    def add_shortcut(self, site):
+        """Add an ikiwiki shortcut to frontpage."""
+        shortcut = frontpage.Shortcut('shortcut-ikiwiki-' + site, site,
+                                      icon='ikiwiki', url='/ikiwiki/' + site,
+                                      clients=clients)
+        self.add(shortcut)
+        return shortcut
+
+    def remove_shortcut(self, site):
+        """Remove an ikiwiki shortcut from frontpage."""
+        component = self.remove('shortcut-ikiwiki-' + site)
+        component.remove()  # Remove from global list.
+
 
 def init():
     """Initialize the ikiwiki module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-edit', 'ikiwiki:index',
-                     short_description)
+    global app
+    app = IkiwikiApp()
     register_group(group)
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(
-            'ikiwiki', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-
-        if is_enabled():
-            add_shortcuts()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'ikiwiki', ['setup'])
-    global service
-    if service is None:
-        service = service_module.Service(
-            'ikiwiki', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcuts)
-
-
-def add_shortcuts():
-    sites = actions.run('ikiwiki', ['get-sites']).split('\n')
-    sites = [name for name in sites if name != '']
-    for site in sites:
-        frontpage.add_shortcut('ikiwiki_' + site, site, url='/ikiwiki/' + site,
-                               login_required=False, icon='ikiwiki')
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return action_utils.webserver_is_enabled('ikiwiki-plinth')
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('ikiwiki', ['enable'])
-    add_shortcuts()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('ikiwiki', ['disable'])
-    frontpage.remove_shortcut('ikiwiki*')
+    helper.call('post', app.enable)
 
 
 def diagnose():
