@@ -21,20 +21,18 @@ FreedomBox app for infinoted.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import actions
-from plinth import action_utils
-from plinth import cfg
-from plinth import frontpage
-from plinth import service as service_module
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import ServiceView
-from .manifest import clients
+from plinth.views import AppView
+
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 1
 
-service = None
-
 managed_services = ['infinoted']
 
 managed_packages = ['infinoted']
@@ -54,74 +52,63 @@ description = [
 
 clients = clients
 
+port_forwarding_info = [('TCP', 6523)]
+
+app = None
+
+
+class InfinotedApp(app_module.App):
+    """FreedomBox app for infinoted."""
+
+    app_id = 'infinoted'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-infinoted', name, short_description,
+                              'infinoted', 'infinoted:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-infinoted', name, short_description=short_description,
+            icon='infinoted', description=description,
+            configure_url=reverse_lazy('infinoted:index'), clients=clients,
+            login_required=False)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-infinoted', name,
+                            ports=['infinoted-plinth'], is_external=True)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-infinoted', managed_services[0])
+        self.add(daemon)
+
 
 def init():
     """Initialize the infinoted module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-pencil', 'infinoted:index',
-                     short_description)
+    global app
+    app = InfinotedApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(
-            managed_services[0],
-            name,
-            ports=['infinoted-plinth'],
-            is_external=True,
-            enable=enable,
-            disable=disable)
-
-        if service.is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
-class InfinotedServiceView(ServiceView):
-    service_id = managed_services[0]
-    diagnostics_module_name = "infinoted"
+class InfinotedAppView(AppView):
+    app_id = 'infinoted'
+    diagnostics_module_name = 'infinoted'
+    name = name
     description = description
     clients = clients
+    port_forwarding_info = port_forwarding_info
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'infinoted', ['setup'])
-    global service
-    if service is None:
-        service = service_module.Service(
-            managed_services[0],
-            name,
-            ports=['infinoted-plinth'],
-            is_external=True,
-            enable=enable,
-            disable=disable)
-
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut(
-        'infinoted',
-        name,
-        short_description=short_description,
-        url=None,
-        details=description,
-        configure_url=reverse_lazy('infinoted:index'),
-        login_required=False)
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('service', ['enable', managed_services[0]])
-    add_shortcut()
-
-
-def disable():
-    """Disable the module."""
-    actions.superuser_run('service', ['disable', managed_services[0]])
-    frontpage.remove_shortcut('infinoted')
+    helper.call('post', app.enable)
 
 
 def diagnose():
