@@ -18,16 +18,16 @@
 FreedomBox app to configure XMPP web client/jsxc.
 """
 
+import logging
+
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
-import logging
-import socket
 
-from plinth import frontpage
-from plinth import service as service_module
-from plinth.menu import main_menu
-from .manifest import clients
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.modules.firewall.components import Firewall
 
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -38,68 +38,50 @@ name = _('JSXC')
 short_description = _('Chat Client')
 
 description = [
-
     _('JSXC is a web client for XMPP. Typically it is used with an XMPP '
       'server running locally.'),
 ]
 
 clients = clients
 
-service = None
-
 logger = logging.getLogger(__name__)
 
+app = None
+
+
+class JSXCApp(app_module.App):
+    """FreedomBox app for JSXC."""
+
+    app_id = 'jsxc'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-jsxc', name, short_description, 'jsxc',
+                              'jsxc:index', parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-jsxc', name=name, short_description=short_description,
+            icon='jsxc', url=reverse_lazy('jsxc:jsxc'), clients=clients)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-jsxc', name, ports=['http', 'https'],
+                            is_external=True)
+        self.add(firewall)
+
 
 def init():
     """Initialize the JSXC module"""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'jsxc', 'jsxc:index', short_description)
+    global app
+    app = JSXCApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(
-            'jsxc', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-
-    global service
-    if not service:
-        service = service_module.Service(
-            'jsxc', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut('jsxc', name=name,
-                           short_description=short_description,
-                           url=reverse_lazy('jsxc:jsxc'),
-                           login_required=True)
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    setup_helper = globals()['setup_helper']
-    return setup_helper.get_state() != 'needs-setup'
-
-
-def get_domainname():
-    """Return the domainname"""
-    fqdn = socket.getfqdn()
-    return '.'.join(fqdn.split('.')[1:])
-
-
-def enable():
-    add_shortcut()
-
-
-def disable():
-    frontpage.remove_shortcut('jsxc')
+    helper.call('post', app.enable)
