@@ -14,25 +14,22 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 URLs for the Let's Encrypt module.
 """
 
 from django.conf.urls import url
-from . import views
 
+from . import views
 
 urlpatterns = [
     url(r'^sys/letsencrypt/$', views.index, name='index'),
-    url(r'^sys/letsencrypt/revoke/(?P<domain>[^/]+)/$', views.revoke,
-        name='revoke'),
     url(r'^sys/letsencrypt/obtain/(?P<domain>[^/]+)/$', views.obtain,
         name='obtain'),
+    url(r'^sys/letsencrypt/re-obtain/(?P<domain>[^/]+)/$', views.reobtain,
+        name='re-obtain'),
+    url(r'^sys/letsencrypt/revoke/(?P<domain>[^/]+)/$', views.revoke,
+        name='revoke'),
     url(r'^sys/letsencrypt/delete/(?P<domain>[^/]+)/$', views.delete,
         name='delete'),
-    url(r'^sys/letsencrypt/toggle_hooks/(?P<domain>[^/]+)/$',
-        views.toggle_hooks, name='toggle_hooks'),
-    url(r'^sys/letsencrypt/toggle_module/(?P<domain>[^/]+)/'
-        '(?P<module>[^/]+)/$', views.toggle_module, name='toggle_module'),
 ]
