@@ -26,9 +26,8 @@ from django.views.generic import FormView
 
 from plinth import actions
 from plinth.forms import DomainSelectionForm
-from plinth.modules import matrixsynapse
-from plinth.utils import get_domain_names
-from plinth.views import ServiceView
+from plinth.modules import matrixsynapse, names
+from plinth.views import AppView
 
 from . import get_public_registration_status
 from .forms import MatrixSynapseForm
@@ -42,10 +41,7 @@ class SetupView(FormView):
 
     def form_valid(self, form):
         """Handle valid form submission."""
-        domain_name = form.cleaned_data['domain_name']
-        actions.superuser_run('matrixsynapse',
-                              ['setup', '--domain-name', domain_name])
-
+        matrixsynapse.setup_domain(form.cleaned_data['domain_name'])
         return super().form_valid(form)
 
     def get_context_data(self, *args, **kwargs):
@@ -54,18 +50,21 @@ class SetupView(FormView):
 
         context['title'] = matrixsynapse.name
         context['description'] = matrixsynapse.description
-        context['domain_names'] = get_domain_names()
+        context['domain_names'] = names.components.DomainName.list_names(
+            'matrix-synapse-plinth')
 
         return context
 
 
-class MatrixSynapseServiceView(ServiceView):
+class MatrixSynapseAppView(AppView):
     """Show matrix-synapse service page."""
-    service_id = matrixsynapse.managed_services[0]
+    app_id = 'matrixsynapse'
     template_name = 'matrix-synapse.html'
+    name = matrixsynapse.name
     description = matrixsynapse.description
     diagnostics_module_name = 'matrixsynapse'
     form_class = MatrixSynapseForm
+    port_forwarding_info = matrixsynapse.port_forwarding_info
 
     def dispatch(self, request, *args, **kwargs):
         """Redirect to setup page if setup is not done yet."""
@@ -80,13 +79,14 @@ class MatrixSynapseServiceView(ServiceView):
         context['domain_name'] = matrixsynapse.get_configured_domain_name()
         context['clients'] = matrixsynapse.clients
         context['manual_page'] = matrixsynapse.manual_page
+        context['certificate_status'] = matrixsynapse.get_certificate_status()
         return context
 
     def get_initial(self):
         """Return the values to fill in the form."""
         initial = super().get_initial()
         initial.update({
-            'enable_public_registration': get_public_registration_status()
+            'enable_public_registration': get_public_registration_status(),
         })
         return initial
 
@@ -105,11 +105,9 @@ class MatrixSynapseServiceView(ServiceView):
                 messages.info(self.request, _('Setting unchanged'))
         elif not app_same:
             if new_config['is_enabled']:
-                self.service.enable()
-                messages.success(self.request, _('Application enabled'))
+                self.app.enable()
             else:
-                self.service.disable()
-                messages.success(self.request, _('Application disabled'))
+                self.app.disable()
 
         if not pubreg_same:
             # note action public-registration restarts, if running now
@@ -124,4 +122,4 @@ class MatrixSynapseServiceView(ServiceView):
                 messages.success(self.request,
                                  _('Public registration disabled'))
 
-        return super(ServiceView, self).form_valid(form)
+        return super().form_valid(form)
