@@ -23,22 +23,24 @@ from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
 from plinth.modules import minetest, names
-from plinth.views import ServiceView
+from plinth.views import AppView
 
-from . import description, get_configuration, managed_services
+from . import description, get_configuration
 from .forms import MinetestForm
 
 
-class MinetestServiceView(ServiceView):  # pylint: disable=too-many-ancestors
+class MinetestAppView(AppView):  # pylint: disable=too-many-ancestors
     """A specialized view for configuring minetest."""
-    service_id = managed_services[0]
-    diagnostics_module_name = "minetest"
+    app_id = 'minetest'
+    diagnostics_module_name = 'minetest'
+    name = minetest.name
     description = description
     show_status_block = True
     template_name = 'minetest.html'
     form_class = MinetestForm
     clients = minetest.clients
     manual_page = minetest.manual_page
+    port_forwarding_info = minetest.port_forwarding_info
 
     def get_initial(self):
         """Return the values to fill in the form."""
@@ -49,10 +51,8 @@ class MinetestServiceView(ServiceView):  # pylint: disable=too-many-ancestors
     def get_context_data(self, *args, **kwargs):
         """Add service to the context data."""
         context = super().get_context_data(*args, **kwargs)
-        domains = [
-            domain for domains in names.domains.values() for domain in domains
-        ]
-        context['domains'] = domains
+        context['domains'] = names.components.DomainName.list_names(
+            'minetest-plinth')
         return context
 
     def form_valid(self, form):
@@ -61,7 +61,7 @@ class MinetestServiceView(ServiceView):  # pylint: disable=too-many-ancestors
         old_config = get_configuration()
 
         if old_config['max_players'] != data['max_players'] \
-           and data['max_players'] != None:
+           and data['max_players'] is not None:
             actions.superuser_run(
                 'minetest',
                 ['configure', '--max_players',
