@@ -21,14 +21,16 @@ FreedomBox app to configure OpenVPN server.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, cfg, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
-version = 2
+from .manifest import backup # noqa, pylint: disable=unused-import
 
-service = None
+version = 3
 
 managed_services = ['openvpn-server@freedombox']
 
@@ -51,44 +53,59 @@ description = [
 
 manual_page = 'OpenVPN'
 
+port_forwarding_info = [('UDP', 1194)]
+
+app = None
+
+
+class OpenVPNApp(app_module.App):
+    """FreedomBox app for OpenVPN."""
+
+    app_id = 'openvpn'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-openvpn', name, short_description,
+                              'openvpn', 'openvpn:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        download_profile = \
+            format_lazy(_('<a class="btn btn-primary btn-sm" href="{link}">'
+                          'Download Profile</a>'),
+                        link=reverse_lazy('openvpn:profile'))
+        shortcut = frontpage.Shortcut(
+            'shortcut-openvpn', name, short_description=short_description,
+            icon='openvpn', description=description + [download_profile],
+            configure_url=reverse_lazy('openvpn:index'), login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-openvpn', name, ports=['openvpn'],
+                            is_external=True)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-openvpn', managed_services[0])
+        self.add(daemon)
+
 
 def init():
     """Initialize the OpenVPN module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'openvpn', 'openvpn:index',
-                     short_description)
+    global app
+    app = OpenVPNApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['openvpn'], is_external=True)
-
-        if service.is_enabled() and is_setup():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled() \
+       and is_setup():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'openvpn', ['upgrade'])
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['openvpn'], is_external=True,
-                                         enable=enable, disable=disable)
-
-
-def add_shortcut():
-    """Add shortcut in frontpage."""
-    download_profile = \
-        format_lazy(_('<a class="btn btn-primary btn-sm" href="{link}">'
-                      'Download Profile</a>'),
-                    link=reverse_lazy('openvpn:profile'))
-    frontpage.add_shortcut(
-        'openvpn', name, short_description=short_description,
-        details=description + [download_profile],
-        configure_url=reverse_lazy('openvpn:index'), login_required=True)
+    if app.is_enabled() and is_setup():
+        helper.call('post', app.enable)
 
 
 def is_setup():
@@ -96,18 +113,6 @@ def is_setup():
     return actions.superuser_run('openvpn', ['is-setup']).strip() == 'true'
 
 
-def enable():
-    """Enable the module."""
-    actions.superuser_run('service', ['enable', managed_services[0]])
-    add_shortcut()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('service', ['disable', managed_services[0]])
-    frontpage.remove_shortcut('openvpn')
-
-
 def diagnose():
     """Run diagnostics and return the results."""
     return [action_utils.diagnose_port_listening(1194, 'udp4')]
