@@ -18,18 +18,19 @@
 FreedomBox app for configuring OpenVPN server.
 """
 
+import logging
+
 from django.contrib import messages
 from django.http import HttpResponse
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.utils.translation import ugettext as _
 from django.views.decorators.http import require_POST
-import logging
+
+from plinth import actions, daemon
+from plinth.modules import config, openvpn
 
 from .forms import OpenVpnForm
-from plinth import actions
-from plinth.modules import openvpn
-from plinth.modules import config
 
 logger = logging.getLogger(__name__)
 
@@ -55,24 +56,26 @@ def index(request):
     else:
         form = OpenVpnForm(initial=status, prefix='openvpn')
 
-    return TemplateResponse(request, 'openvpn.html',
-                            {'title': openvpn.name,
-                             'description': openvpn.description,
-                             'status': status,
-                             'form': form})
+    return TemplateResponse(
+        request, 'openvpn.html', {
+            'title': openvpn.name,
+            'description': openvpn.description,
+            'manual_page': openvpn.manual_page,
+            'port_forwarding_info': openvpn.port_forwarding_info,
+            'status': status,
+            'form': form
+        })
 
 
 @require_POST
 def setup(request):
     """Start the setup process."""
-    openvpn.service.notify_enabled(None, True)
-
     global setup_process
     if not openvpn.is_setup() and not setup_process:
         setup_process = actions.superuser_run('openvpn', ['setup'],
                                               run_in_background=True)
 
-    openvpn.add_shortcut()
+    openvpn.app.enable()
 
     return redirect('openvpn:index')
 
@@ -102,8 +105,8 @@ def get_status():
     return {
         'is_setup': openvpn.is_setup(),
         'setup_running': bool(setup_process),
-        'enabled': openvpn.service.is_enabled(),
-        'is_running': openvpn.service.is_running()
+        'enabled': openvpn.app.is_enabled(),
+        'is_running': daemon.app_is_running(openvpn.app)
     }
 
 
@@ -133,9 +136,9 @@ def _apply_changes(request, old_status, new_status):
 
     if old_status['enabled'] != new_status['enabled']:
         if new_status['enabled']:
-            openvpn.enable()
+            openvpn.app.enable()
         else:
-            openvpn.disable()
+            openvpn.app.disable()
 
         modified = True
 
