@@ -20,16 +20,20 @@ FreedomBox app to configure PageKite.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import cfg
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import cfg, menu
+from plinth.modules.names.components import DomainType
 from plinth.utils import format_lazy
 
 from . import utils
+from .manifest import backup  # noqa, pylint: disable=unused-import
 
 version = 1
 
 depends = ['names']
 
+managed_services = ['pagekite']
+
 managed_packages = ['pagekite']
 
 first_boot_steps = [
@@ -52,8 +56,8 @@ description = [
           'the rest of the Internet. This includes the following '
           'situations:'), box_name=_(cfg.box_name)),
     format_lazy(
-        _('{box_name} is behind a restricted firewall.'), box_name=_(
-            cfg.box_name)),
+        _('{box_name} is behind a restricted firewall.'),
+        box_name=_(cfg.box_name)),
     format_lazy(
         _('{box_name} is connected to a (wireless) router which you '
           'don\'t control.'), box_name=_(cfg.box_name)),
@@ -73,12 +77,37 @@ description = [
 
 manual_page = 'PageKite'
 
+app = None
+
+
+class PagekiteApp(app_module.App):
+    """FreedomBox app for Pagekite."""
+
+    app_id = 'pagekite'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-pagekite', name, short_description,
+                              'fa-flag', 'pagekite:index',
+                              parent_url_name='system')
+        self.add(menu_item)
+
+        domain_type = DomainType('domain-type-pagekite', _('PageKite Domain'),
+                                 'pagekite:index', can_have_certificate=True)
+        self.add(domain_type)
+
+        # XXX: Add pagekite daemon component and simplify action script
+
 
 def init():
-    """Intialize the PageKite module"""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-flag', 'pagekite:index',
-                     short_description)
+    """Initialize the PageKite module"""
+    global app
+    app = PagekiteApp()
+
+    setup_helper = globals()['setup_helper']
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
     # Register kite name with Name Services module.
     utils.update_names_module(initial_registration=True)
@@ -87,3 +116,4 @@ def init():
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
+    helper.call('post', app.enable)
