@@ -21,11 +21,15 @@ FreedomBox app to configure Privoxy.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, cfg, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import ServiceView
+from plinth.views import AppView
+
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -56,63 +60,59 @@ description = [
 
 reserved_usernames = ['privoxy']
 
-service = None
-
 manual_page = 'Privoxy'
 
+app = None
+
+
+class PrivoxyApp(app_module.App):
+    """FreedomBox app for Privoxy."""
+
+    app_id = 'privoxy'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-privoxy', name, short_description,
+                              'privoxy', 'privoxy:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-privoxy', name, short_description=short_description,
+            icon='privoxy', description=description,
+            configure_url=reverse_lazy('privoxy:index'), login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-privoxy', name, ports=['privoxy'],
+                            is_external=False)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-privoxy', managed_services[0])
+        self.add(daemon)
+
 
 def init():
-    """Intialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'privoxy', 'privoxy:index',
-                     short_description)
+    """Initialize the module."""
+    global app
+    app = PrivoxyApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['privoxy'], is_external=False,
-                                         enable=enable, disable=disable)
-
-        if service.is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.call('pre', actions.superuser_run, 'privoxy', ['pre-install'])
     helper.install(managed_packages)
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name,
-                                         ports=['privoxy'], is_external=False,
-                                         enable=enable, disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
+    helper.call('post', app.enable)
 
 
-def add_shortcut():
-    frontpage.add_shortcut(
-        'privoxy', name, short_description=short_description,
-        details=description, configure_url=reverse_lazy('privoxy:index'),
-        login_required=True)
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('service', ['enable', managed_services[0]])
-    add_shortcut()
-
-
-def disable():
-    """Disable the module."""
-    actions.superuser_run('service', ['disable', managed_services[0]])
-    frontpage.remove_shortcut('privoxy')
-
-
-class PrivoxyServiceView(ServiceView):
-    service_id = managed_services[0]
+class PrivoxyAppView(AppView):
+    app_id = 'privoxy'
     diagnostics_module_name = 'privoxy'
+    name = name
     description = description
     manual_page = manual_page
 
