@@ -21,18 +21,18 @@ FreedomBox app for Quassel.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, cfg, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import ServiceView
+from plinth.views import AppView
 
-from .manifest import clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 1
 
-service = None
-
 managed_services = ['quasselcore']
 
 managed_packages = ['quassel-core']
@@ -63,61 +63,63 @@ reserved_usernames = ['quasselcore']
 
 manual_page = 'Quassel'
 
+port_forwarding_info = [('TCP', 4242)]
+
+app = None
+
+
+class QuasselApp(app_module.App):
+    """FreedomBox app for Quassel."""
+
+    app_id = 'quassel'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-quassel', name, short_description,
+                              'quassel', 'quassel:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-quassel', name, short_description=short_description,
+            icon='quassel', description=description,
+            configure_url=reverse_lazy('quassel:index'), clients=clients,
+            login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-quassel', name, ports=['quassel-plinth'],
+                            is_external=True)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-quassel', managed_services[0])
+        self.add(daemon)
+
 
 def init():
     """Initialize the quassel module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'quassel', 'quassel:index',
-                     short_description)
+    global app
+    app = QuasselApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name, ports=[
-            'quassel-plinth'
-        ], is_external=True, enable=enable, disable=disable)
-
-        if service.is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
-class QuasselServiceView(ServiceView):
-    service_id = managed_services[0]
-    diagnostics_module_name = "quassel"
+class QuasselAppView(AppView):
+    app_id = 'quassel'
+    diagnostics_module_name = 'quassel'
+    name = name
     description = description
     clients = clients
     manual_page = manual_page
+    port_forwarding_info = port_forwarding_info
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name, ports=[
-            'quassel-plinth'
-        ], is_external=True, enable=enable, disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut(
-        'quassel', name, short_description=short_description,
-        details=description, configure_url=reverse_lazy('quassel:index'),
-        login_required=True)
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('service', ['enable', managed_services[0]])
-    add_shortcut()
-
-
-def disable():
-    """Disable the module."""
-    actions.superuser_run('service', ['disable', managed_services[0]])
-    frontpage.remove_shortcut('quassel')
+    helper.call('post', app.enable)
 
 
 def diagnose():
