@@ -14,16 +14,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 URLs for the radicale module.
 """
 
 from django.conf.urls import url
 
-from .views import RadicaleServiceView
-
+from .views import RadicaleAppView
 
 urlpatterns = [
-    url(r'^apps/radicale/$', RadicaleServiceView.as_view(), name='index'),
+    url(r'^apps/radicale/$', RadicaleAppView.as_view(), name='index'),
 ]
