@@ -20,11 +20,13 @@ FreedomBox app to configure Roundcube.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 
-from .manifest import backup, clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -56,26 +58,46 @@ description = [
 
 clients = clients
 
-service = None
-
 manual_page = 'Roundcube'
 
+app = None
+
+
+class RoundcubeApp(app_module.App):
+    """FreedomBox app for Roundcube."""
+
+    app_id = 'roundcube'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-roundcube', name, short_description,
+                              'roundcube', 'roundcube:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut('shortcut-roundcube', name,
+                                      short_description=short_description,
+                                      icon='roundcube', url='/roundcube/',
+                                      clients=clients, login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-roundcube', name,
+                            ports=['http', 'https'], is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-roundcube', 'roundcube')
+        self.add(webserver)
+
 
 def init():
-    """Intialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'roundcube', 'roundcube:index',
-                     short_description)
+    """Initialize the module."""
+    global app
+    app = RoundcubeApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(
-            'roundcube', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
@@ -83,35 +105,7 @@ def setup(helper, old_version=None):
     helper.call('pre', actions.superuser_run, 'roundcube', ['pre-install'])
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'roundcube', ['setup'])
-    helper.call('post', add_shortcut)
-    global service
-    if service is None:
-        service = service_module.Service(
-            'roundcube', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-
-
-def add_shortcut():
-    frontpage.add_shortcut('roundcube', name,
-                           short_description=short_description,
-                           url='/roundcube', login_required=True)
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return action_utils.webserver_is_enabled('roundcube')
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('roundcube', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('roundcube', ['disable'])
-    frontpage.remove_shortcut('roundcube')
+    helper.call('post', app.enable)
 
 
 def diagnose():
