@@ -20,9 +20,10 @@ FreedomBox app to configure Shaarli.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, frontpage
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 
 from .manifest import clients
 
@@ -44,58 +45,49 @@ description = [
 
 clients = clients
 
-service = None
-
 manual_page = 'Shaarli'
 
+app = None
+
+
+class ShaarliApp(app_module.App):
+    """FreedomBox app for Shaarli."""
+
+    app_id = 'shaarli'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-shaarli', name, short_description,
+                              'shaarli', 'shaarli:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut('shortcut-shaarli', name,
+                                      short_description=short_description,
+                                      icon='shaarli', url='/shaarli',
+                                      clients=clients, login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-shaarli', name, ports=['http', 'https'],
+                            is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-shaarli', 'shaarli')
+        self.add(webserver)
+
 
 def init():
     """Initialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'fa-bookmark', 'shaarli:index',
-                     short_description)
+    global app
+    app = ShaarliApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(
-            'shaarli', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-    global service
-    if service is None:
-        service = service_module.Service(
-            'shaarli', name, ports=['http', 'https'], is_external=True,
-            is_enabled=is_enabled, enable=enable, disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut('shaarli', name,
-                           short_description=short_description, url='/shaarli',
-                           login_required=True)
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return action_utils.webserver_is_enabled('shaarli')
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('shaarli', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('shaarli', ['disable'])
-    frontpage.remove_shortcut('shaarli')
+    helper.call('post', app.enable)
