@@ -22,10 +22,13 @@ import json
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import actions, cfg
-from plinth.menu import main_menu
+from plinth import actions
+from plinth import app as app_module
+from plinth import cfg, menu
 from plinth.utils import format_lazy
 
+from .manifest import backup # noqa, pylint: disable=unused-import
+
 version = 1
 
 name = _('Sharing')
@@ -33,15 +36,31 @@ name = _('Sharing')
 description = [
     format_lazy(
         _('Sharing allows you to share files and folders on your {box_name} '
-          'over the web with chosen groups of users.'), box_name=_(
-              cfg.box_name))
+          'over the web with chosen groups of users.'),
+        box_name=_(cfg.box_name))
 ]
 
+app = None
+
+
+class SharingApp(app_module.App):
+    """FreedomBox app for sharing files."""
+
+    app_id = 'sharing'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-sharing', name, None, 'sharing',
+                              'sharing:index', parent_url_name='apps')
+        self.add(menu_item)
+
 
 def init():
     """Initialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'sharing', 'sharing:index')
+    global app
+    app = SharingApp()
+    app.set_enabled(True)
 
 
 def list_shares():
@@ -50,11 +69,12 @@ def list_shares():
     return json.loads(output)['shares']
 
 
-def add_share(name, path, groups):
+def add_share(name, path, groups, is_public):
     """Add a new share by called the action script."""
-    actions.superuser_run(
-        'sharing',
-        ['add', '--name', name, '--path', path, '--groups'] + groups)
+    args = ['add', '--name', name, '--path', path, '--groups'] + groups
+    if is_public:
+        args.append('--is-public')
+    actions.superuser_run('sharing', args)
 
 
 def remove_share(name):
