@@ -18,15 +18,19 @@
 FreedomBox app to manage filesystem snapshots.
 """
 
-import augeas
 import json
 
+import augeas
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import menu
+from plinth.modules import storage
 
-version = 3
+from .manifest import backup # noqa, pylint: disable=unused-import
+
+version = 4
 
 managed_packages = ['snapper']
 
@@ -37,35 +41,61 @@ description = [
       'These can be used to roll back the system to a previously known '
       'good state in case of unwanted changes to the system.'),
     # Translators: xgettext:no-python-format
-    _('Snapshots are taken every hour, day and month (called timeline '
-      'snapshots). Snapshots are also taken before and after a software '
-      'installation. Although snapshots are efficient and only store the '
-      'differences, they may be deleted to reclaim free space.  Individual '
-      'files from older snapshots can be accessed by visiting "/.snapshots" '
-      'directory in the filesystem. It is recommended to enable snapshots '
-      'only if you have at least 50% free space on your root partition.'),
-    _('Snapshots work on btrfs file systems only and on the root '
-      'partition only. Snapshots are not a replacement for backups since '
-      'they are stored on the same partition. ')
+    _('Snapshots are taken periodically (called timeline snapshots) and also '
+      'before and after a software installation. Older snapshots will be '
+      'automatically cleaned up according to the settings below.'),
+    _('Snapshots currently work on btrfs file systems only and on the root '
+      'partition only. Snapshots are not a replacement for '
+      '<a href="/plinth/sys/backups">backups</a> since '
+      'they can only be stored on the same partition. ')
 ]
 
-service = None
-
 manual_page = 'Snapshots'
 
 DEFAULT_FILE = '/etc/default/snapper'
 
+fs_types_supported = ['btrfs']
+
+app = None
+
+
+class SnapshotApp(app_module.App):
+    """FreedomBox app for snapshots."""
+
+    app_id = 'snapshot'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-snapshot', name, None, 'fa-film',
+                              'snapshot:index', parent_url_name='system')
+        self.add(menu_item)
+
 
 def init():
     """Initialize the module."""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-film', 'snapshot:index')
+    global app
+    app = SnapshotApp()
+
+    setup_helper = globals()['setup_helper']
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
+
+
+def is_supported():
+    """Return whether snapshots are support on current setup."""
+    fs_type = storage.get_filesystem_type()
+    return fs_type in fs_types_supported
 
 
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-    helper.call('post', actions.superuser_run, 'snapshot', ['setup'])
+    if is_supported():
+        helper.call('post', actions.superuser_run, 'snapshot',
+                    ['setup', '--old-version',
+                     str(old_version)])
+        helper.call('post', app.enable)
 
 
 def load_augeas():
@@ -94,21 +124,29 @@ def get_configuration():
     def get_boolean_choice(status):
         return ('yes', 'Enabled') if status else ('no', 'Disabled')
 
+    def get_max_from_range(key):
+        return output[key].split('-')[-1]
+
     return {
         'enable_timeline_snapshots':
             get_boolean_choice(output['TIMELINE_CREATE'] == 'yes'),
         'enable_software_snapshots':
             get_boolean_choice(is_apt_snapshots_enabled(aug)),
         'hourly_limit':
-            output['TIMELINE_LIMIT_HOURLY'],
+            get_max_from_range('TIMELINE_LIMIT_HOURLY'),
         'daily_limit':
-            output['TIMELINE_LIMIT_DAILY'],
+            get_max_from_range('TIMELINE_LIMIT_DAILY'),
         'weekly_limit':
-            output['TIMELINE_LIMIT_WEEKLY'],
-        'yearly_limit':
-            output['TIMELINE_LIMIT_YEARLY'],
+            get_max_from_range('TIMELINE_LIMIT_WEEKLY'),
         'monthly_limit':
-            output['TIMELINE_LIMIT_MONTHLY'],
-        'number_min_age':
-            round(int(output['NUMBER_MIN_AGE']) / 86400),
+            get_max_from_range('TIMELINE_LIMIT_MONTHLY'),
+        'yearly_limit':
+            get_max_from_range('TIMELINE_LIMIT_YEARLY'),
+        'free_space':
+            output['FREE_LIMIT'],
     }
+
+
+def restore_post(packet):
+    """Run after restore."""
+    actions.superuser_run('snapshot', ['kill-daemon'])
