@@ -25,8 +25,8 @@ from . import views
 urlpatterns = [
     url(r'^sys/snapshot/$', views.index, name='index'),
     url(r'^sys/snapshot/manage/$', views.manage, name='manage'),
-    url(r'^sys/snapshot/(?P<number>\d+)/delete$', views.delete, name='delete'),
-    url(r'^sys/snapshot/all/delete$', views.delete_all, name='delete-all'),
+    url(r'^sys/snapshot/selected/delete$', views.delete_selected,
+        name='delete-selected'),
     url(r'^sys/snapshot/(?P<number>\d+)/rollback$', views.rollback,
         name='rollback'),
 ]
