@@ -21,9 +21,13 @@ FreedomBox app for OpenSSH server.
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
-from plinth import service as service_module
-from plinth.menu import main_menu
-from plinth.views import ServiceView
+from plinth import app as app_module
+from plinth import menu
+from plinth.daemon import Daemon
+from plinth.modules.firewall.components import Firewall
+from plinth.views import AppView
+
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -42,17 +46,37 @@ description = [
       'using such connections.')
 ]
 
-service = None
+port_forwarding_info = [('TCP', 22)]
+
+app = None
+
+
+class SSHApp(app_module.App):
+    """FreedomBox app for SSH."""
+
+    app_id = 'ssh'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-ssh', name, None, 'fa-terminal',
+                              'ssh:index', parent_url_name='system')
+        self.add(menu_item)
+
+        firewall = Firewall('firewall-ssh', name, ports=['ssh'],
+                            is_external=True)
+        self.add(firewall)
+
+        daemon = Daemon('daemon-ssh', managed_services[0])
+        self.add(daemon)
 
 
 def init():
-    """Intialize the ssh module."""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-console', 'ssh:index')
-
-    global service
-    service = service_module.Service(
-        managed_services[0], name, ports=['ssh'], is_external=True)
+    """Initialize the ssh module."""
+    global app
+    app = SSHApp()
+    if app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
@@ -60,6 +84,8 @@ def setup(helper, old_version=None):
     actions.superuser_run('ssh', ['setup'])
 
 
-class SshServiceView(ServiceView):
-    service_id = managed_services[0]
+class SshAppView(AppView):
+    app_id = 'ssh'
+    name = name
     description = description
+    port_forwarding_info = port_forwarding_info
