@@ -18,9 +18,15 @@
 Forms for the Single Sign On app of FreedomBox.
 """
 
-from django.contrib.auth.forms import AuthenticationForm as DjangoAuthenticationForm
 from captcha.fields import CaptchaField
+from django.contrib.auth.forms import \
+    AuthenticationForm as DjangoAuthenticationForm
 
 
 class AuthenticationForm(DjangoAuthenticationForm):
+    """Authentication form with an additional Captcha field."""
     captcha = CaptchaField()
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.fields['username'].widget.attrs.update({'autofocus': 'autofocus'})
