@@ -23,15 +23,16 @@ import os
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils
-from plinth import actions
-from plinth import cfg
-from plinth import frontpage
-from plinth import service as service_module
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import cfg, frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
 from .errors import TahoeConfigurationError
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -43,7 +44,10 @@ name = _('Tahoe-LAFS')
 
 short_description = _('Distributed File Storage')
 
-service = None
+port_forwarding_info = [
+    ('TCP', 3456),
+    ('TCP', 5678),
+]
 
 tahoe_home = '/var/lib/tahoe-lafs'
 introducer_name = 'introducer'
@@ -54,6 +58,46 @@ introducers_file = os.path.join(
 introducer_furl_file = os.path.join(
     tahoe_home, '{0}/private/{0}.furl'.format(introducer_name))
 
+app = None
+
+
+class TahoeApp(app_module.App):
+    """FreedomBox app for Tahoe LAFS."""
+
+    app_id = 'tahoe'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-tahoe', name, short_description,
+                              'tahoe-lafs', 'tahoe:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-tahoe', name, short_description=short_description,
+            icon='tahoe-lafs', url=None, login_required=True)
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-tahoe', name, ports=['tahoe-plinth'],
+                            is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-tahoe', 'tahoe-plinth')
+        self.add(webserver)
+
+        daemon = Daemon('daemon-tahoe', managed_services[0])
+        self.add(daemon)
+
+
+class Shortcut(frontpage.Shortcut):
+    """Frontpage shortcut to use configured domain name for URL."""
+
+    def enable(self):
+        """Set the proper shortcut URL when enabled."""
+        super().enable()
+        self.url = 'https://{}:5678'.format(get_configured_domain_name())
+
 
 def is_setup():
     """Check whether Tahoe-LAFS is setup"""
@@ -79,31 +123,19 @@ description = [
     format_lazy(
         _('This {box_name} hosts a storage node and an introducer by default. '
           'Additional introducers can be added, which will introduce this '
-          'node to the other storage nodes.'),
-        box_name=_(cfg.box_name)),
+          'node to the other storage nodes.'), box_name=_(cfg.box_name)),
 ]
 
 
 def init():
-    """Intialize the module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'tahoe-lafs', 'tahoe:index', short_description)
+    """Initialize the module."""
+    global app
+    app = TahoeApp()
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and is_setup():
-        service = service_module.Service(
-            managed_services[0],
-            name,
-            ports=['tahoe-plinth'],
-            is_external=True,
-            is_enabled=is_enabled,
-            enable=enable,
-            disable=disable,
-            is_running=is_running)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and is_setup() \
+       and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
@@ -115,81 +147,34 @@ def post_setup(configured_domain_name):
     """Actions to be performed after installing tahoe-lafs package."""
     actions.superuser_run('tahoe-lafs',
                           ['setup', '--domain-name', configured_domain_name])
-    actions.superuser_run('tahoe-lafs', ['enable'])
     actions.run_as_user('tahoe-lafs', ['create-introducer'],
                         become_user='tahoe-lafs')
     actions.run_as_user('tahoe-lafs', ['create-storage-node'],
                         become_user='tahoe-lafs')
     actions.superuser_run('tahoe-lafs', ['autostart'])
-
-    global service
-    if service is None:
-        service = service_module.Service(
-            managed_services[0],
-            name,
-            ports=['tahoe-plinth'],
-            is_external=True,
-            is_enabled=is_enabled,
-            enable=enable,
-            disable=disable,
-            is_running=is_running)
-    service.notify_enabled(None, True)
-    add_shortcut()
-
-
-def add_shortcut():
-    """Helper method to add a shortcut to the front page."""
-    # BUG: Current logo appears squashed on front page.
-    frontpage.add_shortcut(
-        'tahoe-lafs', name, short_description=short_description,
-        url='https://{}:5678'.format(get_configured_domain_name()),
-        login_required=True)
-
-
-def is_running():
-    """Return whether the service is running."""
-    return action_utils.service_is_running(managed_services[0])
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return (action_utils.service_is_enabled(managed_services[0]) and
-            action_utils.webserver_is_enabled('tahoe-plinth'))
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('tahoe-lafs', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('tahoe-lafs', ['disable'])
-    frontpage.remove_shortcut('tahoe-lafs')
+    app.enable()
 
 
 def diagnose():
     """Run diagnostics and return the results."""
-    return [action_utils.diagnose_url(
-        'http://localhost:5678', kind='4', check_certificate=False),
-            action_utils.diagnose_url(
-                'http://localhost:5678', kind='6', check_certificate=False),
-            action_utils.diagnose_url(
-                'http://{}:5678'.format(get_configured_domain_name()),
-                kind='4',
-                check_certificate=False)]
+    return [
+        action_utils.diagnose_url('http://localhost:5678', kind='4',
+                                  check_certificate=False),
+        action_utils.diagnose_url('http://localhost:5678', kind='6',
+                                  check_certificate=False),
+        action_utils.diagnose_url(
+            'http://{}:5678'.format(get_configured_domain_name()), kind='4',
+            check_certificate=False)
+    ]
 
 
 def add_introducer(introducer):
     """Add an introducer to the storage node's list of introducers.
     Param introducer must be a tuple of (pet_name, furl)
     """
-    actions.run_as_user('tahoe-lafs',
-                        ['add-introducer',
-                         "--introducer",
-                         ",".join(introducer)],
-                        become_user='tahoe-lafs')
+    actions.run_as_user(
+        'tahoe-lafs', ['add-introducer', "--introducer", ",".join(introducer)],
+        become_user='tahoe-lafs')
 
 
 def remove_introducer(pet_name):
