@@ -19,11 +19,12 @@ FreedomBox app for configuring Tor.
 """
 from django.contrib import messages
 from django.template.response import TemplateResponse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext as _
 
 from plinth import actions
 from plinth.errors import ActionError
 from plinth.modules import tor
+from plinth.modules.firewall.components import Firewall
 
 from . import utils as tor_utils
 from .forms import TorForm
@@ -57,7 +58,8 @@ def index(request):
             'manual_page': tor.manual_page,
             'status': status,
             'config_running': bool(config_process),
-            'form': form
+            'form': form,
+            'firewall': tor.app.get_components_of_type(Firewall)
         })
 
 
@@ -66,10 +68,10 @@ def _apply_changes(request, old_status, new_status):
     try:
         __apply_changes(request, old_status, new_status)
     except ActionError as exception:
-        messages.error(request,
-                       _('Action error: {0} [{1}] [{2}]').format(
-                           exception.args[0], exception.args[1],
-                           exception.args[2]))
+        messages.error(
+            request,
+            _('Action error: {0} [{1}] [{2}]').format(
+                exception.args[0], exception.args[1], exception.args[2]))
 
 
 def __apply_changes(request, old_status, new_status):
@@ -123,6 +125,12 @@ def __apply_changes(request, old_status, new_status):
     if old_status['enabled'] != new_status['enabled']:
         arg_value = 'enable' if new_status['enabled'] else 'disable'
         arguments.extend(['--service', arg_value])
+        # XXX: Perform app enable/disable within the background process
+        if new_status['enabled']:
+            tor.app.enable()
+        else:
+            tor.app.disable()
+
         config_process = actions.superuser_run(
             'tor', ['configure'] + arguments, run_in_background=True)
         return
@@ -154,8 +162,6 @@ def _collect_config_result(request):
 
     status = tor_utils.get_status()
 
-    tor.socks_service.notify_enabled(None, status['enabled'])
-    tor.bridge_service.notify_enabled(None, status['enabled'])
     tor.update_hidden_service_domain(status)
 
     if not return_code:
