@@ -22,12 +22,15 @@ import json
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
-from plinth import action_utils, actions, frontpage
-from plinth.menu import main_menu
+from plinth import action_utils, actions
+from plinth import app as app_module
+from plinth import frontpage, menu
+from plinth.daemon import Daemon
+from plinth.modules.apache.components import Webserver
+from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import register_group
 
-from .manifest import clients
+from .manifest import backup, clients # noqa, pylint: disable=unused-import
 
 version = 2
 
@@ -52,28 +55,50 @@ reserved_usernames = ['debian-transmission']
 
 group = ('bit-torrent', _('Download files using BitTorrent applications'))
 
-service = None
-
 manual_page = 'Transmission'
 
+app = None
+
+
+class TransmissionApp(app_module.App):
+    """FreedomBox app for Transmission."""
+
+    app_id = 'transmission'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-transmission', name, short_description,
+                              'transmission', 'transmission:index',
+                              parent_url_name='apps')
+        self.add(menu_item)
+
+        shortcut = frontpage.Shortcut(
+            'shortcut-transmission', name, short_description=short_description,
+            icon='transmission', url='/transmission', clients=clients,
+            login_required=True, allowed_groups=[group[0]])
+        self.add(shortcut)
+
+        firewall = Firewall('firewall-transmission', name,
+                            ports=['http', 'https'], is_external=True)
+        self.add(firewall)
+
+        webserver = Webserver('webserver-transmission', 'transmission-plinth')
+        self.add(webserver)
+
+        daemon = Daemon('daemon-transmission', managed_services[0])
+        self.add(daemon)
+
 
 def init():
-    """Intialize the Transmission module."""
-    menu = main_menu.get('apps')
-    menu.add_urlname(name, 'transmission', 'transmission:index',
-                     short_description)
+    """Initialize the Transmission module."""
+    global app
+    app = TransmissionApp()
     register_group(group)
 
-    global service
     setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup':
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable)
-
-        if is_enabled():
-            add_shortcut()
+    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
+        app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
@@ -88,40 +113,7 @@ def setup(helper, old_version=None):
                 ['merge-configuration'],
                 input=json.dumps(new_configuration).encode())
 
-    helper.call('post', actions.superuser_run, 'transmission', ['enable'])
-    global service
-    if service is None:
-        service = service_module.Service(managed_services[0], name, ports=[
-            'http', 'https'
-        ], is_external=True, is_enabled=is_enabled, enable=enable,
-                                         disable=disable)
-    helper.call('post', service.notify_enabled, None, True)
-    helper.call('post', add_shortcut)
-
-
-def add_shortcut():
-    frontpage.add_shortcut('transmission', name,
-                           short_description=short_description,
-                           url='/transmission', login_required=True,
-                           allowed_groups=[group[0]])
-
-
-def is_enabled():
-    """Return whether the module is enabled."""
-    return (action_utils.service_is_enabled('transmission-daemon')
-            and action_utils.webserver_is_enabled('transmission-plinth'))
-
-
-def enable():
-    """Enable the module."""
-    actions.superuser_run('transmission', ['enable'])
-    add_shortcut()
-
-
-def disable():
-    """Enable the module."""
-    actions.superuser_run('transmission', ['disable'])
-    frontpage.remove_shortcut('transmission')
+    helper.call('post', app.enable)
 
 
 def diagnose():
