@@ -17,11 +17,19 @@
 
 from django.utils.translation import ugettext_lazy as _
 
+from plinth.modules.backups.api import validate as validate_backup
 from plinth.clients import store_url, validate
 
-_package_id = 'org.ttrssreader'
-
 clients = validate([{
+    'name':
+        _('Tiny Tiny RSS (Fork)'),
+    'platforms': [{
+        'type': 'store',
+        'os': 'android',
+        'store_name': 'f-droid',
+        'url': store_url('f-droid', 'org.fox.tttrss')
+    }]
+}, {
     'name':
         _('Tiny Tiny RSS'),
     'platforms': [{
@@ -33,18 +41,14 @@ clients = validate([{
         'type': 'web',
         'url': '/tt-rss'
     }]
-}, {
-    'name':
-        _('TT-RSS Reader'),
-    'platforms': [{
-        'type': 'store',
-        'os': 'android',
-        'store_name': 'google-play',
-        'url': store_url('google-play', _package_id),
-    }, {
-        'type': 'store',
-        'os': 'android',
-        'store_name': 'f-droid',
-        'url': store_url('f-droid', _package_id),
-    }]
 }])
+
+backup = validate_backup({
+    'data': {
+        'files': ['/var/lib/plinth/backups-data/ttrss-database.sql']
+    },
+    'secrets': {
+        'files': ['/etc/tt-rss/database.php']
+    },
+    'services': ['tt-rss']
+})
