@@ -20,9 +20,11 @@ FreedomBox app for upgrades.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
 from plinth import actions
-from plinth.menu import main_menu
+from plinth import app as app_module
+from plinth import menu
+
+from .manifest import backup # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -30,27 +32,35 @@ is_essential = True
 
 managed_packages = ['unattended-upgrades']
 
-name = _('Software Upgrades')
+name = _('Update')
 
 description = [
-    _('Upgrades install the latest software and security updates. When '
-      'automatic upgrades are enabled, upgrades are automatically run every '
-      'night. You don\'t normally need to start the upgrade process.')
+    _('Check for and apply the latest software and security updates.')
 ]
 
-service = None
-
 manual_page = 'Upgrades'
 
+app = None
+
+
+class UpgradesApp(app_module.App):
+    """FreedomBox app for software upgrades."""
+
+    app_id = 'upgrades'
+
+    def __init__(self):
+        """Create components for the app."""
+        super().__init__()
+        menu_item = menu.Menu('menu-upgrades', name, None, 'fa-refresh',
+                              'upgrades:index', parent_url_name='system')
+        self.add(menu_item)
+
 
 def init():
     """Initialize the module."""
-    menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-refresh', 'upgrades:index')
-    global service
-    service = service_module.Service('auto-upgrades', name, is_external=False,
-                                     is_enabled=is_enabled, enable=enable,
-                                     disable=disable)
+    global app
+    app = UpgradesApp()
+    app.set_enabled(True)
 
 
 def setup(helper, old_version=None):
