@@ -32,6 +32,6 @@ backups_ssh_repo_uuid = 'plinth_test_sshfs'  # will be mounted to /media/<uuid>
 
 # Import config_local to override the default variables
 try:
-    from .config_local import *
+    from .config_local import * # noqa, pylint: disable=unused-import
 except ImportError:
     pass
