@@ -24,10 +24,13 @@ import os
 import random
 import re
 import string
+from distutils.version import LooseVersion
 
 import ruamel.yaml
 from django.utils.functional import lazy
 
+Version = LooseVersion  # Abstraction over distutils.version.LooseVersion
+
 
 def import_from_gi(library, version):
     """Import and return a GObject introspection library."""
@@ -53,7 +56,7 @@ format_lazy = lazy(_format_lazy, str)
 
 
 def non_admin_view(func):
-    """Decorator to mark a view as accesible by non-admin users."""
+    """Decorator to mark a view as accessible by non-admin users."""
     setattr(func, 'IS_NON_ADMIN', True)
     return func
 
@@ -71,34 +74,17 @@ def is_user_admin(request, cached=False):
     return user_is_admin
 
 
-def get_domain_names():
-    """Return the domain name(s)"""
-    from plinth.modules import names
-
-    domain_names = []
-
-    for domain_type, domains in names.domains.items():
-        if domain_type == 'hiddenservice':
-            continue
-        for domain in domains:
-            domain_names.append((domain, domain))
-
-    return domain_names
-
-
 class YAMLFile(object):
     """A context management class for updating YAML files"""
 
-    def __init__(self, yaml_file, post_exit=None):
+    def __init__(self, yaml_file):
         """Return a context object for the YAML file.
 
         Parameters:
         yaml_file - the YAML file to update.
-        post_exit - a function that will be called after
         updating the YAML file.
         """
         self.yaml_file = yaml_file
-        self.post_exit = post_exit
         self.conf = None
 
     def __enter__(self):
@@ -110,17 +96,22 @@ class YAMLFile(object):
 
             return self.conf
 
-    def __exit__(self, typ, value, traceback):
-        with open(self.yaml_file, 'w') as intro_conf:
-            ruamel.yaml.round_trip_dump(self.conf, intro_conf)
-
-        if self.post_exit:
-            self.post_exit()
+    def __exit__(self, type_, value, traceback):
+        if not traceback:
+            with open(self.yaml_file, 'w') as intro_conf:
+                ruamel.yaml.round_trip_dump(self.conf, intro_conf)
 
     def is_file_empty(self):
         return os.stat(self.yaml_file).st_size == 0
 
 
+def random_string(size=8):
+    """Generate a random alphanumeric string."""
+    chars = (random.SystemRandom().choice(string.ascii_letters)
+             for _ in range(size))
+    return ''.join(chars)
+
+
 def generate_password(size=32):
     """Generate a random password using ascii alphabet and digits."""
     chars = (random.SystemRandom().choice(string.ascii_letters + string.digits)
@@ -158,3 +149,14 @@ def gunzip(gzip_file, output_file):
 
 def is_non_empty_file(file_path):
     return os.path.isfile(file_path) and os.path.getsize(file_path) > 0
+
+
+def is_axes_old():
+    """Return true if using django-axes version strictly less than 5.0.0.
+
+    XXX: Remove this method and allow code that uses it after django-axes >=
+    5.0.0 becomes available in Debian stable.
+
+    """
+    import axes
+    return LooseVersion(axes.get_version()) < LooseVersion('5.0')
